Class: Tryouts::OrphanBlock
- Inherits:
-
Data
- Object
- Data
- Tryouts::OrphanBlock
- Includes:
- EvalAnchor
- Defined in:
- lib/tryouts/test_case.rb
Overview
Code with no description and no expectations that sits between test cases. Executed in source order for its side effects, but never evaluated against expectations and never counted in test tallies.
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
Returns the value of attribute code.
-
#first_code_line ⇒ Object
readonly
Returns the value of attribute first_code_line.
-
#line_range ⇒ Object
readonly
Returns the value of attribute line_range.
-
#path ⇒ Object
readonly
Returns the value of attribute path.
Instance Method Summary collapse
- #empty? ⇒ Boolean
-
#initialize(first_code_line: nil, **rest) ⇒ OrphanBlock
constructor
A new instance of OrphanBlock.
Methods included from EvalAnchor
Constructor Details
#initialize(first_code_line: nil, **rest) ⇒ OrphanBlock
Returns a new instance of OrphanBlock.
95 96 97 |
# File 'lib/tryouts/test_case.rb', line 95 def initialize(first_code_line: nil, **rest) super end |
Instance Attribute Details
#code ⇒ Object (readonly)
Returns the value of attribute code
92 93 94 |
# File 'lib/tryouts/test_case.rb', line 92 def code @code end |
#first_code_line ⇒ Object (readonly)
Returns the value of attribute first_code_line
92 93 94 |
# File 'lib/tryouts/test_case.rb', line 92 def first_code_line @first_code_line end |
#line_range ⇒ Object (readonly)
Returns the value of attribute line_range
92 93 94 |
# File 'lib/tryouts/test_case.rb', line 92 def line_range @line_range end |
#path ⇒ Object (readonly)
Returns the value of attribute path
92 93 94 |
# File 'lib/tryouts/test_case.rb', line 92 def path @path end |
Instance Method Details
#empty? ⇒ Boolean
99 100 101 |
# File 'lib/tryouts/test_case.rb', line 99 def empty? code.empty? end |